@@ -5,6 +5,10 @@
  * easily in restrictive environments by removing features.
  * ============================================================ */
 
+#ifndef CMAKE
+/* Only use the compile time options defined here from the standard Makefile. */
+
+
 /* Uncomment to compile with tcpd/libwrap support. */
 //#define WITH_WRAP
 
@@ -44,6 +48,8 @@
  */
 #define WITH_BRIDGE
 
+#endif
+
 /* ============================================================
  * Compatibility defines
  *
