@@ -27,10 +27,12 @@ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include <config.h>
+
 #include <assert.h>
 #include <stdio.h>
-#include <stdint.h>
 #include <string.h>
+
 #include <mqtt3.h>
 #include <memory_mosq.h>
 #include <util_mosq.h>
